#ifndef _DRV_API_H
#define _DRV_API_H
/****************************************************************************
                              Copyright (c) 2009
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

/**
   \file drv_api.h
      This file contains the defines, the structures declarations,
      the tables declarations and the global functions declarations.
      It is the main configuration file for the project and can be adapted
      to own needs.

   \remarks
      Compiler switch for OS is needed. Use LINUX for linux and VXWORKS for
      VxWorks.
*/

/**
 \mainpage VMMC Driver Description
 \section DRV_INTEGRATION Integrating the Driver
 \subsection COMP_SWITCHES Compiler Switches
 - LINUX        - must be specified for LINUX
 - VXWORKS      - must be specified for VxWorks
 - DEBUG        - enables debug features as asserts for example
 - ENABLE_TRACE - enables print out to terminal
*/

/* ============================= */
/* Global Defines                */
/* ============================= */

/* define prototypes for VxWorks 5 */
#ifndef __PROTOTYPE_5_0
   #define __PROTOTYPE_5_0
#endif

#ifdef HAVE_CONFIG_H
#include "drv_config.h"
/*lint -save -e(19)  we need this ; to stop a runaway arguments from breaking
  out of drv_config.h */
;
/*lint -restore */
#else
#error no drv_config.h
#endif

/* ============================= */
/* includes                      */
/* ============================= */

/* this included file is supposed to support following OS:
   - LINUX
   - VXWORKS
*/
#include "drv_vmmc_osmap.h"

/* device specific headers to implement the device specific "hook"
   functionality, such as PCM GPIO multiplex control */
#if   defined(SYSTEM_DANUBE)
   #include "drv_vmmc_danube.h"
#elif defined(SYSTEM_AR9) || defined(SYSTEM_VR9)
   #include "drv_vmmc_amazon_s.h"
#elif defined(SYSTEM_FALCON)
   #include "drv_vmmc_falcon.h"
#elif defined(SYSTEM_XRX300)
   #include "drv_vmmc_xrx300.h"
#endif


/* ============================= */
/* define mapping                */
/* ============================= */

/* define features depending on user controled defines and other defines */

#if   defined(SYSTEM_DANUBE)
   #define VMMC_FEAT_SLIC_DC
#elif defined(SYSTEM_AR9)
   #define VMMC_FEAT_SMARTSLIC
   #define VMMC_FEAT_VPE1_SW_WD
#elif defined(SYSTEM_VR9)
   #define VMMC_FEAT_SMARTSLIC
   #define VMMC_FEAT_VPE1_SW_WD
#elif defined(SYSTEM_FALCON)
   #define VMMC_FEAT_SMARTSLIC
#elif defined(SYSTEM_XRX300)
   #define VMMC_FEAT_SMARTSLIC
   #define VMMC_FEAT_VPE1_SW_WD
#else
#error Please check your platform selection (configure --with-device=xxx)
#endif

/* defined unconditionally */
#define VMMC_FEAT_PACKET
#define TAPI_PACKET 1

#ifdef TAPI_FAX_T38
   #define VMMC_FEAT_FAX_T38
   #define VMMC_FEAT_PACKET
#endif

#ifdef TAPI_FAX_T38_FW
   #define VMMC_FEAT_FAX_T38_FW
   #define VMMC_FEAT_PACKET
#endif

#ifdef HDLC_SUPPORT
   #define VMMC_FEAT_HDLC
   #define VMMC_FEAT_KPI
   #define VMMC_FEAT_PACKET
#endif

#ifdef KPI_SUPPORT
   #define VMMC_FEAT_KPI
   #define VMMC_FEAT_PACKET
#endif

#ifdef PCM_SUPPORT
   #define VMMC_FEAT_PCM
#endif

#ifdef TAPI_ANNOUNCEMENTS
   #define VMMC_FEAT_ANNOUNCEMENTS
#endif

#ifdef TAPI_LT
   #define VMMC_FEAT_LT
#endif

#ifdef TAPI_GR909
   #define VMMC_FEAT_GR909
#endif

/* Callibration feature requires a SmartSLIC */
#if defined(CALIBRATION_SUPPORT) && defined(VMMC_FEAT_SMARTSLIC)
   #define VMMC_FEAT_CALIBRATION
#endif

/* Continuous measurement feature requires a SmartSLIC */
#if defined(TAPI_CONT_MEASUREMENT) && defined(VMMC_FEAT_SMARTSLIC)
   #define VMMC_FEAT_CONT_MEASUREMENT
#endif

/* FXS Phone Detection feature requires a SmartSLIC */
#if defined(TAPI_PHONE_DETECTION) && defined(VMMC_FEAT_SMARTSLIC)
   #define VMMC_FEAT_PHONE_DETECTION
#endif

/* Metering feature requires a SmartSLIC */
#if defined(TAPI_METERING) &&  defined(VMMC_FEAT_SMARTSLIC)
   #define VMMC_FEAT_METERING
#endif

/* Message waiting lamp feature requires a SmartSLIC */
#if defined(VMMC_FEAT_SMARTSLIC)
   #define VMMC_FEAT_MWL
#endif

/* ============================= */
/* safety check                  */
/* ============================= */
#if defined(VMMC_FEAT_SLIC_DC) && defined(VMMC_FEAT_SMARTSLIC)
#error STOP - Conflict in SLIC selection!
#endif

#endif /* _DRV_API_H */
